==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/RequiredExecutablePropertySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.ExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.RequirementSet;
import io.ciera.tool.sql.ooaofooa.component.impl.ExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.RequirementSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredSignalSetImpl;
import io.ciera.tool.sql.ooaofooa.value.MessageValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.MessageValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class RequiredExecutablePropertySetImpl extends InstanceSet<RequiredExecutablePropertySet,RequiredExecutableProperty> implements RequiredExecutablePropertySet {

    // attributes
    @Override
    public void setId( UniqueId m_Id ) throws XtumlException {
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredexecutableproperty.setId( m_Id );
    }
    @Override
    public void setRequirement_Id( UniqueId ref_Requirement_Id ) throws XtumlException {
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredexecutableproperty.setRequirement_Id( ref_Requirement_Id );
    }
    @Override
    public void setExecutableProperty_Id( UniqueId ref_ExecutableProperty_Id ) throws XtumlException {
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredexecutableproperty.setExecutableProperty_Id( ref_ExecutableProperty_Id );
    }


    // selections
    @Override
    public ExecutablePropertySet R4500_implements_ExecutableProperty() throws XtumlException {
        ExecutablePropertySet executablepropertyset = new ExecutablePropertySetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) executablepropertyset.add( requiredexecutableproperty.R4500_implements_ExecutableProperty() );
        return executablepropertyset;
    }
    @Override
    public RequirementSet R4500_is_implemented_by_Requirement() throws XtumlException {
        RequirementSet requirementset = new RequirementSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requirementset.add( requiredexecutableproperty.R4500_is_implemented_by_Requirement() );
        return requirementset;
    }
    @Override
    public RequiredOperationSet R4502_is_a_RequiredOperation() throws XtumlException {
        RequiredOperationSet requiredoperationset = new RequiredOperationSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredoperationset.add( requiredexecutableproperty.R4502_is_a_RequiredOperation() );
        return requiredoperationset;
    }
    @Override
    public RequiredSignalSet R4502_is_a_RequiredSignal() throws XtumlException {
        RequiredSignalSet requiredsignalset = new RequiredSignalSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredsignalset.add( requiredexecutableproperty.R4502_is_a_RequiredSignal() );
        return requiredsignalset;
    }
    @Override
    public MessageValueSet R845_MessageValue() throws XtumlException {
        MessageValueSet messagevalueset = new MessageValueSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) messagevalueset.addAll( requiredexecutableproperty.R845_MessageValue() );
        return messagevalueset;
    }


    @Override
    public RequiredExecutableProperty nullElement() {
        return RequiredExecutablePropertyImpl.EMPTY_REQUIREDEXECUTABLEPROPERTY;
    }

    @Override
    public RequiredExecutablePropertySet emptySet() {
      return new RequiredExecutablePropertySetImpl();
    }

    @Override
    public RequiredExecutablePropertySet value() {
        return this;
    }

    @Override
    public List<RequiredExecutableProperty> elements() {
        return Arrays.asList(toArray(new RequiredExecutableProperty[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/RequiredExecutablePropertySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.ExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.RequirementSet;
import io.ciera.tool.sql.ooaofooa.component.impl.ExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.RequirementSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.RequiredSignalSetImpl;
import io.ciera.tool.sql.ooaofooa.value.MessageValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.MessageValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class RequiredExecutablePropertySetImpl extends InstanceSet<RequiredExecutablePropertySet,RequiredExecutableProperty> implements RequiredExecutablePropertySet {

    public RequiredExecutablePropertySetImpl() {
    }

    public RequiredExecutablePropertySetImpl(Comparator<? super RequiredExecutableProperty> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId m_Id ) throws XtumlException {
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredexecutableproperty.setId( m_Id );
    }
    @Override
    public void setExecutableProperty_Id( UniqueId ref_ExecutableProperty_Id ) throws XtumlException {
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredexecutableproperty.setExecutableProperty_Id( ref_ExecutableProperty_Id );
    }
    @Override
    public void setRequirement_Id( UniqueId ref_Requirement_Id ) throws XtumlException {
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredexecutableproperty.setRequirement_Id( ref_Requirement_Id );
    }


    // selections
    @Override
    public ExecutablePropertySet R4500_implements_ExecutableProperty() throws XtumlException {
        ExecutablePropertySet executablepropertyset = new ExecutablePropertySetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) executablepropertyset.add( requiredexecutableproperty.R4500_implements_ExecutableProperty() );
        return executablepropertyset;
    }
    @Override
    public RequirementSet R4500_is_implemented_by_Requirement() throws XtumlException {
        RequirementSet requirementset = new RequirementSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requirementset.add( requiredexecutableproperty.R4500_is_implemented_by_Requirement() );
        return requirementset;
    }
    @Override
    public RequiredOperationSet R4502_is_a_RequiredOperation() throws XtumlException {
        RequiredOperationSet requiredoperationset = new RequiredOperationSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredoperationset.add( requiredexecutableproperty.R4502_is_a_RequiredOperation() );
        return requiredoperationset;
    }
    @Override
    public RequiredSignalSet R4502_is_a_RequiredSignal() throws XtumlException {
        RequiredSignalSet requiredsignalset = new RequiredSignalSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) requiredsignalset.add( requiredexecutableproperty.R4502_is_a_RequiredSignal() );
        return requiredsignalset;
    }
    @Override
    public MessageValueSet R845_MessageValue() throws XtumlException {
        MessageValueSet messagevalueset = new MessageValueSetImpl();
        for ( RequiredExecutableProperty requiredexecutableproperty : this ) messagevalueset.addAll( requiredexecutableproperty.R845_MessageValue() );
        return messagevalueset;
    }


    @Override
    public RequiredExecutableProperty nullElement() {
        return RequiredExecutablePropertyImpl.EMPTY_REQUIREDEXECUTABLEPROPERTY;
    }

    @Override
    public RequiredExecutablePropertySet emptySet() {
      return new RequiredExecutablePropertySetImpl();
    }

    @Override
    public RequiredExecutablePropertySet emptySet(Comparator<? super RequiredExecutableProperty> comp) {
      return new RequiredExecutablePropertySetImpl(comp);
    }

    @Override
    public RequiredExecutablePropertySet value() {
        return this;
    }

    @Override
    public List<RequiredExecutableProperty> elements() {
        return Arrays.asList(toArray(new RequiredExecutableProperty[0]));
    }

}
